Welcome to Rucio’s documentation! — Rucio 1.12.2 documentation

Attention

ATLAS users should refer to https://twiki.cern.ch/twiki/bin/viewauth/AtlasComputing/RucioClientsHowTo instead of this page. This twiki is the entry point for ATLAS users learning the Rucio client. The ATLAS-specific information on this page will be removed.

# Welcome to Rucio’s documentation!

The Rucio project is the new version of ATLAS Distributed Data Management (DDM) system services for allowing the ATLAS collaboration to manage the large volumes of data, both taken by the detector as well as generated or derived, in the ATLAS distributed computing system. Rucio uses to manage accounts, files, datasets and distibuted storage systems.

This documentation is generated by the Sphinx toolkit. and lives in the source tree.

Links:
  - Documentation - http://rucio.cern.ch
  - Project tracker - https://its.cern.ch/jira/browse/RUCIO
  - Code analytics and search services - https://www.ohloh.net/p/rucio/

# Concepts and terminology

The following concepts define how data is organised, accessed, and catalogued by Rucio.

- Rucio account
- Files, Datasets and Containers
- Meta-data attributes
- Rucio Storage Element
- Permission model
- Replica management
- Replication rule examples
- RSE Expressions
- Accounting and quota
- Notifications
- Subscriptions / Policies

# Architecture

- Overview of Rucio Architecture
- Rucio Storage Element Wrapper and Manager
- Scheduled Transfers
- Data deletion
- Rucio Database Schema
- Replication Rules Architecture
- Rules Workflow
- Exception and error handling
- Usecases
- Sequence/flow diagrams

# Developer Documentation

- Development Guidelines
- Setting up a Rucio development environment
- Naming convention for the Rucio database objects

# Installing Rucio

- Installing Rucio Clients
- Installing ATLAS Rucio Clients
- Installing Rucio server
- Server Deployment Model
- ATLAS Rucio Integration Test-bed

# Rucio RESTful API

- General notes
- REST API Examples Using Curl
- REST API Automatic Generated Documentation

# Rucio Python Client APIs

- Rucio Clients
- Rucio Clients Examples
- Account Methods
- AccountLimit Methods
- Scope Methods
- Identity Methods
- Data Identifier Methods
- Meta-data Methods
- RSE Classes
- Replica Methods
- Replication Rule Methods
- Lock Methods
- Subscription Methods
- Constants
- Rucio Exceptions

# Rucio CLI

- Rucio CLI Tools
- Rucio CLI Examples
- Rucio Admin CLI Examples
- Rucio CLI tutorial

# Appendices

- Acronyms and Abbreviations

# Indices and tables

- Index
- Module Index
- Search Page